package com.gx.obe.common.widget.dialog;

import java.math.BigDecimal;
import java.text.MessageFormat;
import java.util.List;

import org.eclipse.nebula.widgets.grid.Grid;
import org.eclipse.nebula.widgets.grid.GridColumn;
import org.eclipse.nebula.widgets.grid.GridItem;
import org.eclipse.swt.SWT;
import org.eclipse.swt.core.MessageDialog;
import org.eclipse.swt.core.listener.TextHintListener;
import org.eclipse.swt.core.utils.SwtUtils;
import org.eclipse.swt.core.utils.WidgetUtils;
import org.eclipse.swt.core.widgets.BigButton;
import org.eclipse.swt.core.widgets.EDialog;
import org.eclipse.swt.custom.CLabel;
import org.eclipse.swt.events.ModifyEvent;
import org.eclipse.swt.events.ModifyListener;
import org.eclipse.swt.events.MouseAdapter;
import org.eclipse.swt.events.MouseEvent;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.graphics.Point;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Combo;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Group;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.swt.widgets.Text;

import com.gx.obe.ColorConstants;
import com.gx.obe.business.enumeration.ProjectRuleEnum;
import com.gx.obe.business.vo.ExchangeRate;
import com.gx.obe.common.widget.composite.UnderlineText;
import com.gx.obe.common.widget.thread.SyncThread;
import com.gx.obe.components.core.Constants;
import com.gx.obe.components.core.enumeration.BidPriceEnum;
import com.gx.obe.components.core.util.MoneyUtils;
import com.gx.obe.message.Messages;
import com.gx.obe.util.utils.BigDecimalUtils;
import com.gx.obe.util.utils.CollectionUtils;
import com.gx.obe.util.utils.NumberFormatUtils;
import com.gx.obe.util.utils.ObjectUtils;
import com.gx.obe.web.entity.Supplier;
import com.gx.obe.web.entity.price.BidPriceResult;
import com.gx.obe.web.entity.tender.TenderProjectRuleEntity;
import com.gx.obe.web.service.BidPriceResultService;
import com.swtdesigner.SWTResourceManager;

/**
 * @Description: 修正投标报价项
 * @author chenxw
 */
public class EditSubBidPriceItemDialog extends EDialog {
	
	private final BidPriceResultService bidPriceResultService = new BidPriceResultService();
	
	private final Supplier supplier;
	private final TenderProjectRuleEntity projectRule;
	
	private Grid priceItemGrid;
	
	private List<BidPriceResult> bidPriceResultList;
	
	private BidPriceResult curBidPriceResult;
	
	private Label resultNameLabel, bidCurrencyLabel, evalCurrencyLabel;
	
	private UnderlineText originalPriceText, bidPriceText, evalPriceText;
	
	private Label originalPriceUnitLabel, addSubPriceUnitLabel, bidPriceUnitLabel, evalPriceUnitLabel;
	
	private Combo floatCombo, addSubCombo;
	
	private UnderlineText floatText, addSubText;
	
	private ModifyListener floatModifyListener, addSubModifyListener, bidPriceModifyListener;
	
	
	private Group evalPriceGroup;
	
	private ExchangeRate exchangeRate;
	
	private UnderlineText exchangeRateText;

	private Composite priceItemComposite;

	private Label exchangeRateDetail;

	private Text modifyReasonText;
	
	/**
	 * @author chenxw
	 * @param parentShell
	 * @param projectRule
	 */
	public EditSubBidPriceItemDialog(Shell parentShell, Supplier supplier, TenderProjectRuleEntity projectRule) {
		super(parentShell);
		this.setTitle(Messages.Step_editPrice);
		this.supplier = supplier;
		this.projectRule = projectRule;
	}
	
	/**
	 * @Description:界面
	 * @author chenxw
	 * @param parent
	 * @return
	 */
	@Override
	protected Control createDialogArea(Composite parent) {
		Composite container = (Composite) super.createDialogArea(parent);
		container.setLayout(new GridLayout(1, false));
		
		Composite composite = new Composite(container, SWT.NONE);
		composite.setBackground(SWTResourceManager.getColor(SWT.COLOR_GRAY));
		GridLayout gl_composite = new GridLayout(2, false);
		gl_composite.horizontalSpacing = 1;
		gl_composite.marginHeight = 1;
		gl_composite.marginWidth = 1;
		composite.setLayout(gl_composite);
		composite.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, true, 1, 1));
		
		priceItemComposite = new Composite(composite, SWT.NONE);
		priceItemComposite.setBackground(SWTResourceManager.getColor(SWT.COLOR_WHITE));
		GridLayout gl_composite_1 = new GridLayout(1, false);
		gl_composite_1.marginHeight = 0;
		gl_composite_1.marginWidth = 0;
		priceItemComposite.setLayout(gl_composite_1);
		priceItemComposite.setLayoutData(new GridData(SWT.FILL, SWT.FILL, false, true, 1, 1));
		
		priceItemGrid = new Grid(priceItemComposite, SWT.NONE);
		priceItemGrid.addSelectionListener(new SelectionAdapter() {
			public void widgetSelected(SelectionEvent e) {
				priceItemSelectedAction();
			}
		});
		GridData gd_grid = new GridData(SWT.FILL, SWT.FILL, true, true, 1, 1);
		gd_grid.widthHint = 220;
		priceItemGrid.setLayoutData(gd_grid);
		priceItemGrid.setItemHeight(Constants.ROW_HIGHT);
		
		GridColumn gridColumn = new GridColumn(priceItemGrid, SWT.CENTER);
		gridColumn.setWidth(200);
		
		Composite composite_2 = new Composite(composite, SWT.NONE);
		GridLayout gl_composite_2 = new GridLayout(1, false);
		gl_composite_2.verticalSpacing = 1;
		gl_composite_2.marginHeight = 0;
		gl_composite_2.marginWidth = 0;
		composite_2.setLayout(gl_composite_2);
		composite_2.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, true, 1, 1));
		
		Composite composite_5 = new Composite(composite_2, SWT.NONE);
		composite_5.setBackground(SWTResourceManager.getColor(SWT.COLOR_WHITE));
		composite_5.setLayout(new GridLayout(3, false));
		composite_5.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false, 1, 1));
		
		resultNameLabel = new Label(composite_5, SWT.CENTER);
		resultNameLabel.setForeground(ColorConstants.FONT_BLACK_COLOR);
		resultNameLabel.setFont(SWTResourceManager.getFont("微软雅黑", 10, SWT.NORMAL));
		resultNameLabel.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false, 1, 1));
		
		Composite composite_3 = new Composite(composite_2, SWT.NONE);
		composite_3.setBackground(SWTResourceManager.getColor(SWT.COLOR_WHITE));
		GridData gd_composite_3 = new GridData(SWT.FILL, SWT.CENTER, false, true, 1, 1);
//		gd_composite_3.widthHint = 450;
		composite_3.setLayoutData(gd_composite_3);
		GridLayout gl_composite_3 = new GridLayout(1, false);
		gl_composite_3.verticalSpacing = 20;
		gl_composite_3.marginHeight = 20;
		gl_composite_3.marginWidth = 20;
		composite_3.setLayout(gl_composite_3);
		
		Group bidPriceGroup = new Group(composite_3, SWT.NONE);
		bidPriceGroup.setForeground(ColorConstants.FONT_BLUE_COLOR);
		bidPriceGroup.setFont(SWTResourceManager.getFont("微软雅黑", 12, SWT.NORMAL));
		bidPriceGroup.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, false, true, 1, 1));
		GridLayout gl_bidPriceGroup = new GridLayout(2, false);
		gl_bidPriceGroup.verticalSpacing = 10;
		bidPriceGroup.setLayout(gl_bidPriceGroup);
		bidPriceGroup.setText(Messages.BidPrice);
		
		Label bidPriceCurrency = new Label(bidPriceGroup, SWT.NONE);
		bidPriceCurrency.setLayoutData(new GridData(SWT.RIGHT, SWT.CENTER, false, false, 1, 1));
		bidPriceCurrency.setText(Messages.Currency + "：");
		bidPriceCurrency.setForeground(ColorConstants.FONT_BLACK_COLOR);
		bidPriceCurrency.setFont(SWTResourceManager.getFont("微软雅黑", 10, SWT.NORMAL));
		
		bidCurrencyLabel = new Label(bidPriceGroup, SWT.NONE);
		bidCurrencyLabel.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, false, false, 1, 1));
		bidCurrencyLabel.setForeground(ColorConstants.FONT_BLACK_COLOR);
		bidCurrencyLabel.setFont(SWTResourceManager.getFont("微软雅黑", 10, SWT.NORMAL));
		
		Label originalBidPriceLabel = new Label(bidPriceGroup, SWT.NONE);
		originalBidPriceLabel.setLayoutData(new GridData(SWT.RIGHT, SWT.CENTER, false, false, 1, 1));
		originalBidPriceLabel.setForeground(ColorConstants.FONT_BLACK_COLOR);
		originalBidPriceLabel.setFont(SWTResourceManager.getFont("微软雅黑", 10, SWT.NORMAL));
		originalBidPriceLabel.setText(Messages.OriginalBidPrice + "：");
		
		Composite group = new Composite(bidPriceGroup, SWT.NONE);
		group.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, false, false, 1, 1));
		group.setLayout(new GridLayout(2, false));
		
		originalPriceText = new UnderlineText(group, SWT.CENTER);
		GridData gd_label_6 = new GridData(SWT.LEFT, SWT.CENTER, false, false, 1, 1);
		gd_label_6.widthHint = 120;
		originalPriceText.setLayoutData(gd_label_6);
		originalPriceText.setEditable(false);
		
		originalPriceUnitLabel = new Label(group, SWT.NONE);
		originalPriceUnitLabel.setFont(SWTResourceManager.getFont("微软雅黑", 10, SWT.NORMAL));
		originalPriceUnitLabel.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false, 1, 1));
		
		Label correctionBidPriceLabel = new Label(bidPriceGroup, SWT.NONE);
		correctionBidPriceLabel.setLayoutData(new GridData(SWT.RIGHT, SWT.CENTER, false, false, 1, 1));
		correctionBidPriceLabel.setFont(SWTResourceManager.getFont("微软雅黑", 10, SWT.NORMAL));
		correctionBidPriceLabel.setForeground(ColorConstants.FONT_BLACK_COLOR);
		correctionBidPriceLabel.setText(Messages.Button_correctionBidPrice + "：");
		
		Composite group_1 = new Composite(bidPriceGroup, SWT.NONE);
		group_1.setLayout(new GridLayout(5, false));
		group_1.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, false, false, 1, 1));
		
		floatCombo = new Combo(group_1, SWT.READ_ONLY);
		floatCombo.addSelectionListener(new SelectionAdapter() {
			public void widgetSelected(SelectionEvent e) {
				floatModifyActrion();
			}
		});
		GridData gd_combo = new GridData(SWT.LEFT, SWT.CENTER, false, false, 1, 1);
		gd_combo.widthHint = 30;
		floatCombo.setLayoutData(gd_combo);
		
		floatModifyListener = new ModifyListener() {
			public void modifyText(ModifyEvent e) {
				floatModifyActrion();
			}
		};
		
		floatText = new UnderlineText(group_1, SWT.CENTER);
		floatText.addModifyListener(floatModifyListener);
		GridData gd_composite_9 = new GridData(SWT.LEFT, SWT.CENTER, false, false, 1, 1);
		gd_composite_9.widthHint = 100;
		floatText.setLayoutData(gd_composite_9);
		
		CLabel label_9 = new CLabel(group_1, SWT.NONE);
		label_9.setText("%");
		
		CLabel modifyReasonLabel = new CLabel(group_1, SWT.NONE);
		modifyReasonLabel.setText(Messages.CorrectReason+"：");
		modifyReasonLabel.setFont(SWTResourceManager.getFont("微软雅黑", 10, SWT.NORMAL));
		modifyReasonLabel.setForeground(ColorConstants.FONT_BLACK_COLOR);
		modifyReasonLabel.setLayoutData(new GridData(SWT.RIGHT, SWT.FILL, true, true, 1, 2));
		
		modifyReasonText = new Text(group_1, SWT.BORDER | SWT.WRAP | SWT.V_SCROLL);
		GridData gd_modifyReasonText = new GridData(SWT.FILL, SWT.FILL, true, true, 1, 2);
		gd_modifyReasonText.widthHint = 250;
		modifyReasonText.setLayoutData(gd_modifyReasonText);
		modifyReasonText.addPaintListener(new TextHintListener(MessageFormat.format(Messages.Tips_pleaseEnter, Messages.CorrectReason)));
		modifyReasonText.setTextLimit(500);
		
		addSubCombo = new Combo(group_1, SWT.READ_ONLY);
		addSubCombo.addSelectionListener(new SelectionAdapter() {
			public void widgetSelected(SelectionEvent e) {
				addSubModifyActrion();
			}
		});
		GridData gd_combo_1 = new GridData(SWT.LEFT, SWT.CENTER, false, false, 1, 1);
		gd_combo_1.widthHint = 30;
		addSubCombo.setLayoutData(gd_combo_1);
		
		addSubModifyListener = new ModifyListener() {
			public void modifyText(ModifyEvent e) {
				addSubModifyActrion();
			}
		};
		
		addSubText = new UnderlineText(group_1, SWT.CENTER);
		addSubText.addModifyListener(addSubModifyListener);
		GridData gd_text = new GridData(SWT.LEFT, SWT.CENTER, false, false, 1, 1);
		gd_text.widthHint = 100;
		addSubText.setLayoutData(gd_text);
		
		addSubPriceUnitLabel = new Label(group_1, SWT.NONE);
		addSubPriceUnitLabel.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, false, false, 1, 1));
		
		Label bidPriceLabel = new Label(bidPriceGroup, SWT.NONE);
		bidPriceLabel.setLayoutData(new GridData(SWT.RIGHT, SWT.CENTER, false, false, 1, 1));
		bidPriceLabel.setText(Messages.BidPrice + "：");
		bidPriceLabel.setForeground(ColorConstants.FONT_BLACK_COLOR);
		bidPriceLabel.setFont(SWTResourceManager.getFont("微软雅黑", 10, SWT.NORMAL));
		
		Composite group_2 = new Composite(bidPriceGroup, SWT.NONE);
		group_2.setLayout(new GridLayout(2, false));
		group_2.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false, 1, 1));
		
		bidPriceModifyListener = new ModifyListener() {
			public void modifyText(ModifyEvent e) {
				bidPriceModifyAction();
			}
		};
		
		bidPriceText = new UnderlineText(group_2, SWT.CENTER);
		bidPriceText.addModifyListener(bidPriceModifyListener);
		GridData gd_composite_8 = new GridData(SWT.LEFT, SWT.CENTER, false, false, 1, 1);
		gd_composite_8.widthHint = 120;
		bidPriceText.setFont(SWTResourceManager.getFont("微软雅黑", 10, SWT.NORMAL));
		bidPriceText.setLayoutData(gd_composite_8);
		
		bidPriceUnitLabel = new Label(group_2, SWT.NONE);
		bidPriceUnitLabel.setFont(SWTResourceManager.getFont("微软雅黑", 10, SWT.NORMAL));
		bidPriceUnitLabel.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false, 1, 1));
		
		evalPriceGroup = new Group(composite_3, SWT.NONE);
		evalPriceGroup.setFont(SWTResourceManager.getFont("微软雅黑", 12, SWT.NORMAL));
		evalPriceGroup.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, true, 1, 1));
		GridLayout gl_evalPriceGroup = new GridLayout(2, false);
		gl_evalPriceGroup.verticalSpacing = 10;
		evalPriceGroup.setLayout(gl_evalPriceGroup);
		evalPriceGroup.setText(Messages.EvaluationPrice);
		
		Label evaluationPriceCurrency = new Label(evalPriceGroup, SWT.NONE);
		evaluationPriceCurrency.setLayoutData(new GridData(SWT.RIGHT, SWT.CENTER, false, false, 1, 1));
		evaluationPriceCurrency.setText(Messages.Currency + "：");
		evaluationPriceCurrency.setForeground(ColorConstants.FONT_BLACK_COLOR);
		evaluationPriceCurrency.setFont(SWTResourceManager.getFont("微软雅黑", 10, SWT.NORMAL));
		
		evalCurrencyLabel = new Label(evalPriceGroup, SWT.NONE);
		evalCurrencyLabel.setFont(SWTResourceManager.getFont("微软雅黑", 10, SWT.NORMAL));
		evalCurrencyLabel.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, false, false, 1, 1));
		
		Label exchangeRateLabel = new Label(evalPriceGroup, SWT.NONE);
		exchangeRateLabel.setLayoutData(new GridData(SWT.RIGHT, SWT.CENTER, false, false, 1, 1));
		exchangeRateLabel.setForeground(ColorConstants.FONT_BLACK_COLOR);
		exchangeRateLabel.setFont(SWTResourceManager.getFont("微软雅黑", 10, SWT.NORMAL));
		exchangeRateLabel.setText(Messages.ExchangeRate + "：");
		
		Composite group_3 = new Composite(evalPriceGroup, SWT.NONE);
		group_3.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, false, false, 1, 1));
		group_3.setLayout(new GridLayout(3, false));
		
		exchangeRateText = new UnderlineText(group_3, SWT.CENTER);
		GridData gd_text_2 = new GridData(SWT.LEFT, SWT.CENTER, false, false, 1, 1);
		gd_text_2.widthHint = 120;
		exchangeRateText.setLayoutData(gd_text_2);
		exchangeRateText.setEditable(false);
		
		exchangeRateDetail = new Label(group_3, SWT.NONE);
		exchangeRateDetail.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false, 1, 1));
		exchangeRateDetail.setText("");
		exchangeRateDetail.setFont(SWTResourceManager.getFont("微软雅黑", 12, SWT.NORMAL));
		
		Label evaluationPriceLabel = new Label(evalPriceGroup, SWT.NONE);
		evaluationPriceLabel.setLayoutData(new GridData(SWT.RIGHT, SWT.CENTER, false, false, 1, 1));
		evaluationPriceLabel.setText(Messages.EvaluationPrice + "：");
		evaluationPriceLabel.setForeground(ColorConstants.FONT_BLACK_COLOR);
		evaluationPriceLabel.setFont(SWTResourceManager.getFont("微软雅黑", 10, SWT.NORMAL));
		
		Composite group_4 = new Composite(evalPriceGroup, SWT.NONE);
		group_4.setLayout(new GridLayout(2, false));
		group_4.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false, 1, 1));
		
		evalPriceText = new UnderlineText(group_4, SWT.CENTER);
		GridData gd_label_10 = new GridData(SWT.LEFT, SWT.CENTER, false, false, 1, 1);
		gd_label_10.widthHint = 120;
		evalPriceText.setLayoutData(gd_label_10);
		evalPriceText.setForeground(ColorConstants.FONT_BLUE_COLOR);
		evalPriceText.setFont(SWTResourceManager.getFont("微软雅黑", 10, SWT.NORMAL));
		evalPriceText.setEditable(false);
		
		evalPriceUnitLabel = new Label(group_4, SWT.NONE);
		evalPriceUnitLabel.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false, 1, 1));
		evalPriceUnitLabel.setFont(SWTResourceManager.getFont("微软雅黑", 10, SWT.NORMAL));
		
		Composite composite_4 = new Composite(composite_2, SWT.NONE);
		composite_4.setBackground(SWTResourceManager.getColor(SWT.COLOR_WHITE));
		composite_4.setLayout(new GridLayout(1, false));
		composite_4.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false, 1, 1));
		
		BigButton saveBtn = new BigButton(composite_4, SWT.NONE);
		saveBtn.addMouseListener(new MouseAdapter() {
			public void mouseUp(MouseEvent e) {
				saveAction();
			}
		});
		saveBtn.setLayoutData(new GridData(SWT.CENTER, SWT.CENTER, true, false, 1, 1));
		saveBtn.setText(Messages.Button_save);
		
		init();
		
		return container;
	}
	
	/**
	 * @Description:初始化
	 * @author chenxw
	 */
	private void init() {
		floatCombo.setItems(new String[] { "上浮", "下浮" });
		addSubCombo.setItems(new String[] { "增加", "减少" });
		
		exchangeRate = projectRule.getParamByKey(ProjectRuleEnum.EXCHANGE_RATE);
		if (null == exchangeRate) {
			exchangeRate = new ExchangeRate();
		}
		
		initBidPriceResultList();
		getShell().pack();
		SwtUtils.setCenter(getShell());
	}
	
	/**
	 * @Description: 获取投标报价项
	 * @author chenxw
	 */
	private void initBidPriceResultList() {
		
		SyncThread syncThread = new SyncThread("正在获取投标报价项，请稍等...", new SyncThread.Runnable() {
			@Override
			public void run() {
				bidPriceResultList = bidPriceResultService.getSupplierBidPriceResultList(supplier.getTenderId(), supplier.getId());
				Display.getDefault().syncExec(new Runnable(){
					public void run(){
						if (CollectionUtils.isNull(bidPriceResultList)) {
							return;
						}
						if(!priceItemGrid.isDisposed()){
							if (bidPriceResultList.size() == 1) {
								WidgetUtils.setControlVisible(priceItemComposite, false);
								priceItemComposite.getParent().layout();
							}
							initPriceItemGrid();
						}
					}
				});
			}
		});
		syncThread.start();
//		ThreadProgressDialog dialog = new ThreadProgressDialog(getShell(), priceItemGrid, "正在获取投标报价项，请稍等...") {
//			public void threadRun() {
//				bidPriceResultList = bidPriceResultService.getSupplierBidPriceResultList(supplier.getTenderId(), supplier.getId());
//			}
//			
//			public void asyncExec() {
//				if (CollectionUtils.isNull(bidPriceResultList)) {
//					return;
//				}
//				if (bidPriceResultList.size() == 1) {
//					WidgetUtils.setControlVisible(priceItemComposite, false);
//				}
//				initPriceItemGrid();
//			}
//		};
//		dialog.open();
	}
	
	/**
	 * @Description:初始化报价项列表
	 * @author chenxw
	 */
	private void initPriceItemGrid() {
		for (BidPriceResult bidPriceResult : bidPriceResultList) {
			GridItem gridItem = new GridItem(priceItemGrid, SWT.NONE);
			gridItem.setText(0, ObjectUtils.getObjString(bidPriceResult.getBidPriceName()));
			gridItem.setBackground(SWTResourceManager.getColor(SWT.COLOR_WHITE));
			gridItem.setForeground(ColorConstants.FONT_BLACK_COLOR);
			gridItem.setFont(SWTResourceManager.getFont("微软雅黑", 12, SWT.BOLD));
		}
		priceItemGrid.setSelection(0);
		priceItemSelectedAction();
	}
	
	/**
	 * @Description: 报价项选中事件
	 * @author chenxw
	 */
	private void priceItemSelectedAction() {
		curBidPriceResult = bidPriceResultList.get(priceItemGrid.getSelectionIndex());
		refreshCurBidPriceResult();
//		evalPriceGroup.setVisible(!isEqualsCurrencyCode());
	}
	
	/**
	 * @Description: 是否相同币种
	 * @author chenxw
	 * @return
	 */
	private boolean isEqualsCurrencyCode() {
		return projectRule.getEvalCurrencyCode().equals(curBidPriceResult.getCurrencyCode());
	}
	
	/**
	 * @Description: 初始化当前报价结果
	 * @author chenxw
	 */
	private void initEvalPriceResult() {
		// 评标币种
		evalCurrencyLabel.setText(ObjectUtils.getObjString(projectRule.getEvalCurrencyName()));
		// 评标单位
		evalPriceUnitLabel.setText(ObjectUtils.getObjString(projectRule.getEvalPriceUnit()));
	}
	
	/**
	 * @Description:刷新当前报价结果
	 * @author chenxw
	 */
	private void refreshCurBidPriceResult() {
		// 头信息
		resultNameLabel.setText(ObjectUtils.getObjString(curBidPriceResult.getBidPriceName()));
		
		if(BidPriceEnum.IS_RATE.equals(curBidPriceResult.getPriceType())) {
			originalPriceText.setText(NumberFormatUtils.format(curBidPriceResult.getBidPrice()));
			bidPriceText.setText(NumberFormatUtils.format(curBidPriceResult.getBidPrice(curBidPriceResult.getFinalBidPrice())));
			exchangeRateDetail.setText("");
			bidCurrencyLabel.setText("/");
			evalCurrencyLabel.setText("/");
			String priceUnit = curBidPriceResult.getPriceUnit("%");
			originalPriceUnitLabel.setText(priceUnit);
			addSubPriceUnitLabel.setText(priceUnit);
			bidPriceUnitLabel.setText(priceUnit);
			evalPriceUnitLabel.setText(priceUnit);
		}else {
			// 投标币种
			bidCurrencyLabel.setText(ObjectUtils.getObjString(curBidPriceResult.getCurrencyName(),BidPriceEnum.CNY_NAME));
			// 投标单位
			String priceUnit = curBidPriceResult.getPriceUnit(projectRule.getPriceUnitUseDefault());
			originalPriceUnitLabel.setText(priceUnit);
			addSubPriceUnitLabel.setText(priceUnit);
			bidPriceUnitLabel.setText(priceUnit);
			// 评标币种
			evalCurrencyLabel.setText(ObjectUtils.getObjString(projectRule.getEvalCurrencyName()));
			// 评标单位
			evalPriceUnitLabel.setText(ObjectUtils.getObjString(projectRule.getEvalPriceUnit()));
			// 原始报价
			originalPriceText.setText(curBidPriceResult.getFormatBidPriceByUnit(projectRule.getPriceUnitUseDefault()));
			// 投标报价
			bidPriceText.setText(curBidPriceResult.getFormatFinalBidPriceByUnit(projectRule.getPriceUnitUseDefault()));
			
			modifyReasonText.setText(ObjectUtils.getObjString(curBidPriceResult.getModifyReason()));
			
			// 汇率
			exchangeRateText.setBigDecimalValue(exchangeRate.get(curBidPriceResult.getCurrencyCode()));
			refreshExchangeRage();
		}
		
		// 评标报价
		refreshEvaluationPrice(curBidPriceResult.getBidPrice());
		
		
		addSubPriceUnitLabel.getParent().layout();
	}
	
	/**
	 * @Description: 汇率
	 * @author chenxw
	 * @return
	 */
	private void refreshExchangeRage() {
		String currencyName = ObjectUtils.getObjString(curBidPriceResult.getCurrencyName(projectRule.getCurrencyName()));
		if(exchangeRateText.getText().length() > 0 && currencyName.length() > 0){
			exchangeRateDetail.setText("1".concat(currencyName).concat("=").concat(exchangeRateText.getText()).concat(projectRule.getEvalCurrencyName()));
		}else {
			exchangeRateDetail.setText("");
		}
	}
	
	/**
	 * @Description:浮动修改事件
	 * @author chenxw
	 */
	private void floatModifyActrion() {
		BigDecimal originalPrice = getOriginalPrice();
		
		BigDecimal floatPrice = BigDecimalUtils.mulIsNull(floatText.getBigDecimalValue(), BigDecimal.valueOf(0.01));
		if (floatCombo.getSelectionIndex() == 1) {
			floatPrice = BigDecimalUtils.mulIsNull(floatPrice, BigDecimal.valueOf(-1));
		}
		
		refreshAddSubText(BigDecimalUtils.mulIsNull(originalPrice, floatPrice));
		refreshBidPriceText(BigDecimalUtils.mulIsNull(originalPrice, BigDecimalUtils.add(floatPrice, BigDecimal.ONE)));
	}
	
	/**
	 * @Description:增减修改事件
	 * @author chenxw
	 */
	private void addSubModifyActrion() {
		BigDecimal originalPrice = getOriginalPrice();
		BigDecimal addSubPrice = null;
		if(BidPriceEnum.IS_RATE.equals(curBidPriceResult.getPriceType())) {
			addSubPrice = ObjectUtils.getObjBigDecimal(addSubText.getText().trim());
		}else {
			addSubPrice = MoneyUtils.getMoneyFromText(addSubText.getText().trim(), curBidPriceResult.getPriceUnit(projectRule.getPriceUnit()));
		}
		if (addSubCombo.getSelectionIndex() == 1) {
			addSubPrice = BigDecimalUtils.mulIsNull(addSubPrice, BigDecimal.valueOf(-1));
		}
		
		refreshFloatText(BigDecimalUtils.div(addSubPrice, originalPrice));
		refreshBidPriceText(BigDecimalUtils.add(originalPrice, addSubPrice));
	}
	
	/**
	 * @Description:投标报价修改事件
	 * @author chenxw
	 */
	private void bidPriceModifyAction() {
		BigDecimal originalPrice = getOriginalPrice();
		
		BigDecimal difference = BigDecimalUtils.sub(getBidPrice(), originalPrice);
		
		refreshFloatText(BigDecimalUtils.div(difference, originalPrice));
		refreshAddSubText(difference);
		refreshEvaluationPrice(getBidPrice());
	}
	
	/**
	 * @Description: 获取原始报价
	 * @author chenxw
	 * @return
	 */
	private BigDecimal getOriginalPrice() {
		if(BidPriceEnum.IS_RATE.equals(curBidPriceResult.getPriceType())) {
			return ObjectUtils.getObjBigDecimal(originalPriceText.getText().trim());
		}else {
			return MoneyUtils.getMoneyFromText(originalPriceText.getText().trim(), curBidPriceResult.getPriceUnit(projectRule.getPriceUnit()));
		}
	}
	
	/**
	 * @Description: 获取投标报价
	 * @author chenxw
	 * @return
	 */
	private BigDecimal getBidPrice() {
		if(BidPriceEnum.IS_RATE.equals(curBidPriceResult.getPriceType())) {
			return ObjectUtils.getObjBigDecimal(bidPriceText.getText().trim());
		}else {
			return MoneyUtils.getMoneyFromText(bidPriceText.getText().trim(), curBidPriceResult.getPriceUnit(projectRule.getPriceUnit()));
		}
	}
	
	/**
	 * @Description: 刷新浮动值
	 * @author chenxw
	 * @param differenceRate
	 */
	private void refreshFloatText(BigDecimal differenceRate) {
		floatCombo.select(0);
		if (BigDecimalUtils.compareTo(differenceRate, BigDecimal.ZERO) == -1) {
			floatCombo.select(1);
			differenceRate = BigDecimalUtils.mulIsNull(differenceRate, BigDecimal.valueOf(-1));
		}
		floatText.removeModifyListener(floatModifyListener);
		floatText.setBigDecimalValue(BigDecimalUtils.round(BigDecimalUtils.mulIsNull(differenceRate, BigDecimal.valueOf(100)), 2));
		floatText.addModifyListener(floatModifyListener);
	}
	
	/**
	 * @Description: 刷新增减值
	 * @author chenxw
	 * @param difference
	 */
	private void refreshAddSubText(BigDecimal difference) {
		addSubCombo.select(0);
		if (BigDecimalUtils.compareTo(difference, BigDecimal.ZERO) == -1) {
			addSubCombo.select(1);
			difference = BigDecimalUtils.mulIsNull(difference, BigDecimal.valueOf(-1));
		}
		difference = BigDecimalUtils.round(difference, 2);
		addSubText.removeModifyListener(addSubModifyListener);
		if(BidPriceEnum.IS_RATE.equals(curBidPriceResult.getPriceType())) {
			addSubText.setText(NumberFormatUtils.format(difference));
		}else {
			addSubText.setText(MoneyUtils.getMoneyFormatByUnit(difference, curBidPriceResult.getPriceUnit(projectRule.getPriceUnit())));
		}
		addSubText.addModifyListener(addSubModifyListener);
	}
	
	/**
	 * @Description: 刷新投标报价
	 * @author chenxw
	 * @param difference
	 */
	private void refreshBidPriceText(BigDecimal bidPrice) {
//		bidPrice = BigDecimalUtils.round(bidPrice, 4);
		bidPriceText.removeModifyListener(bidPriceModifyListener);
		if(BidPriceEnum.IS_RATE.equals(curBidPriceResult.getPriceType())) {
			bidPriceText.setText(NumberFormatUtils.format(bidPrice));
		}else {
			bidPriceText.setText(MoneyUtils.getMoneyFormatByUnit(bidPrice, curBidPriceResult.getPriceUnit(projectRule.getPriceUnit())));
		}
		bidPriceText.addModifyListener(bidPriceModifyListener);
		
		refreshEvaluationPrice(bidPrice);
	}
	
	/**
	 * @Description: 刷新评标价
	 * @author chenxw
	 * @param bidPrice
	 */
	private void refreshEvaluationPrice(BigDecimal bidPrice) {
		if(BidPriceEnum.IS_RATE.equals(curBidPriceResult.getPriceType())) {
			curBidPriceResult.setEvaluationPrice(bidPrice);
			evalPriceText.setText(NumberFormatUtils.format(curBidPriceResult.getEvaluationPrice()));
		}else {
			// 评标报价
			if (isEqualsCurrencyCode()) {
				curBidPriceResult.setEvaluationPrice(bidPrice);
			} else {
				BigDecimal exchangeRate = exchangeRateText.getBigDecimalValue();
				if (exchangeRate != null) {
					curBidPriceResult.setEvaluationPrice(BigDecimalUtils.round(BigDecimalUtils.mul(bidPrice, exchangeRate), 3));
				}
			}
			evalPriceText.setText(curBidPriceResult.getFormatEvaluatoinPriceByUnit(projectRule.getEvalPriceUnit()));
//			initEvalPriceResult();
		}
	}
	
	/**
	 * @Description: 保存事件
	 * @author chenxw
	 */
	private void saveAction() {
		curBidPriceResult.setFinalBidPrice(getBidPrice());
		curBidPriceResult.setModifyReason(modifyReasonText.getText().trim());
		
		if (!isEqualsCurrencyCode() && exchangeRateText.getBigDecimalValue() == null) {
			MessageDialog.openWarning(getShell(), MessageFormat.format(Messages.Tips_notSetFormat, Messages.ExchangeRate));
			return;
		}
		
		ThreadProgressDialog dialog = new ThreadProgressDialog(getShell(), priceItemGrid, "正在保存投标报价项，请稍等...") {
			private boolean success;
			
			public void threadRun() {
				success = bidPriceResultService.updateBidPriceResultOrSum(curBidPriceResult);
			}
			
			public void asyncExec() {
				if (!success) {
					MessageDialog.openError(getShell(), Messages.Tips_saveFail);
					return;
				}
				MessageDialog.openShortMessage(Messages.Tips_saveSuccess);
			}
		};
		dialog.open();
	}
	
	/**
	 * Return the initial size of the dialog.
	 */
	@Override
	protected Point getInitialSize() {
		return new Point(800, 500);
	}
}
