package com.gx.obe.common.widget.dialog;

import org.eclipse.swt.SWT;
import org.eclipse.swt.core.CallBack;
import org.eclipse.swt.core.listener.KeyEnterListener;
import org.eclipse.swt.core.utils.SwtUtils;
import org.eclipse.swt.core.widgets.EButton;
import org.eclipse.swt.core.widgets.EDialog;
import org.eclipse.swt.events.MouseAdapter;
import org.eclipse.swt.events.MouseEvent;
import org.eclipse.swt.graphics.Point;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.swt.widgets.Text;

import com.gx.obe.ColorConstants;
import com.gx.obe.common.icons.IconsActivator;
import com.gx.obe.message.Messages;
import com.swtdesigner.ResourceManager;
import com.swtdesigner.SWTResourceManager;

/**
 * @Description: 
 * @author guoyr
 */
public class InputDialog extends EDialog {
	private EButton confirmBtn;
	private Text text;
	private Label messageLabel;
	private String title;
	private String inputValue = "";
//	private TTSThread TTSThread = null;
	private int minWidth = -1;
	private int minHeight = -1;

	/**
	 * Create the dialog.
	 * @param parentShell
	 */
	public InputDialog(Shell parentShell, String title, String value) {
		super(parentShell);
		setTitle("");
		this.title = title;
		this.inputValue = value;
	}

	/**
	 * Create contents of the dialog.
	 * @param parent
	 */
	@Override
	protected Control createDialogArea(Composite parent) {
		Composite container = (Composite) super.createDialogArea(parent);
		GridLayout gl_container = new GridLayout(1, false);
		gl_container.marginHeight = 10;
		gl_container.marginWidth = 10;
		container.setLayout(gl_container);
		
		messageLabel = new Label(container, SWT.WRAP);
		messageLabel.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false, 1, 1));
		messageLabel.setForeground(ColorConstants.FONT_BLACK_COLOR);
		messageLabel.setFont(SWTResourceManager.getFont("微软雅黑", 10, SWT.NORMAL));
		messageLabel.setText(title);
		
		text = new Text(container, SWT.BORDER);
		GridData gd_text = new GridData(SWT.FILL, SWT.CENTER, false, false, 1, 1);
		gd_text.widthHint = 150;
		text.setLayoutData(gd_text);
		text.setText(null != inputValue?inputValue:"");
			
		Composite composite_1 = new Composite(container, SWT.NONE);
		composite_1.setLayoutData(new GridData(SWT.RIGHT, SWT.CENTER, true, false, 1, 1));
		GridLayout gl_composite_1 = new GridLayout(1, false);
		gl_composite_1.marginHeight = 0;
		gl_composite_1.marginWidth = 0;
		composite_1.setLayout(gl_composite_1);
		
		confirmBtn = new EButton(composite_1, SWT.NONE);
		confirmBtn.addMouseListener(new MouseAdapter() {
			@Override
			public void mouseUp(MouseEvent e) {
				confirmAction();
			}
		});
		GridData gd_confirmBtn = new GridData(SWT.LEFT, SWT.CENTER, false, false, 1, 1);
		confirmBtn.setLayoutData(gd_confirmBtn);
		confirmBtn.setImage(ResourceManager.getPluginImage(IconsActivator.PLUGIN_ID, "icons/btn/blue/ok.png"));
		confirmBtn.setText(Messages.Button_ok);
		init();
		return container;
	}
	
	/**
	 * @Description: 初始化
	 * @author guoyr
	 */
	private void init(){
		
		text.forceFocus();
		// 加入加回车事件
		new KeyEnterListener(getShell(), new CallBack(){
			@Override
			public void callBack() {
				confirmAction();
			}
		});
		if(minWidth > 0 && minHeight > 0){
			this.getShell().setMinimumSize(minWidth, minHeight);
		}
		this.getShell().pack();
		SwtUtils.setCenter(getShell());
	}

	/**
	 * @Description: 确认
	 * @author guoyr
	 */
	private void confirmAction(){
		this.getShell().close();
	}

	public String getInputValue() {
		return inputValue;
	}

	@Override
	public boolean close() {
		inputValue = text.getText().trim();
		return super.close();
	}

	public void setMinSize(int width, int height){
		this.minWidth = width;
		this.minHeight = height;
		
	}
	/**
	 * Return the initial size of the dialog.
	 */
	@Override
	protected Point getInitialSize() {
		return new Point(297, 159);
	}
}
