package com.gx.obe.common.widget.dialog;

import java.util.List;

import org.eclipse.nebula.widgets.grid.Grid;
import org.eclipse.nebula.widgets.grid.GridColumn;
import org.eclipse.nebula.widgets.grid.GridItem;
import org.eclipse.swt.SWT;
import org.eclipse.swt.core.MessageDialog;
import org.eclipse.swt.core.widgets.EButton;
import org.eclipse.swt.core.widgets.EDialog;
import org.eclipse.swt.core.widgets.ESepator;
import org.eclipse.swt.events.MouseAdapter;
import org.eclipse.swt.events.MouseEvent;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.graphics.Point;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Shell;

import com.gx.obe.ColorConstants;
import com.gx.obe.components.core.Constants;
import com.gx.obe.message.Messages;
import com.gx.obe.util.utils.ObjectUtils;
import com.gx.obe.web.entity.Supplier;
import com.swtdesigner.SWTResourceManager;

public class RecommendRankSupplierSelectedDialog extends EDialog {

	private List<Supplier> supplierList;
	private Grid grid;
	private String supplierName;
	private Supplier supplier;

	/**
	 * Create the dialog.
	 * @param parentShell
	 * @param supplierName 
	 */
	public RecommendRankSupplierSelectedDialog(Shell parentShell, List<Supplier> supplierList, String supplierName) {
		super(parentShell);
		setTitle("选择" + supplierName);
		this.supplierList = supplierList;
		this.supplierName = supplierName;
	}

	/**
	 * Create contents of the dialog.
	 * @param parent
	 */
	@Override
	protected Control createDialogArea(Composite parent) {
		Composite container = (Composite) super.createDialogArea(parent);
		container.setBackground(SWTResourceManager.getColor(SWT.COLOR_WHITE));
		container.setBackgroundMode(SWT.INHERIT_FORCE);
		GridLayout gl_container = new GridLayout(1, false);
		gl_container.verticalSpacing = 0;
		gl_container.horizontalSpacing = 0;
		gl_container.marginHeight = 0;
		gl_container.marginWidth = 0;
		container.setLayout(gl_container);
		
		Composite composite = new Composite(container, SWT.NONE);
		GridLayout gl_composite = new GridLayout(1, false);
		gl_composite.verticalSpacing = 0;
		gl_composite.horizontalSpacing = 0;
		gl_composite.marginHeight = 0;
		gl_composite.marginWidth = 0;
		composite.setLayout(gl_composite);
		composite.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, true, 1, 1));
		
		grid = new Grid(composite, SWT.NONE);
		grid.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, true, 1, 1));
		
		GridColumn gridColumn = new GridColumn(grid, SWT.NONE);
		gridColumn.setText("New Column");
		gridColumn.setWidth(5);
		gridColumn.setAlignment(SWT.CENTER);
		
		GridColumn gridColumn_1 = new GridColumn(grid, SWT.NONE);
		gridColumn_1.setText("New Column");
		gridColumn_1.setWidth(500);
		
		ESepator label = new ESepator(container, SWT.NONE);
		label.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false, 4, 1));
		label.setBackground(ColorConstants.SEP_LIGHT_COLOR);
		
		Composite composite_1 = new Composite(container, SWT.NONE);
		composite_1.setLayout(new GridLayout(1, false));
		composite_1.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false, 1, 1));
		
		EButton button = new EButton(composite_1, SWT.NONE);
		button.setBackground(ColorConstants.SKIN_BG);
		button.setForeground(ColorConstants.SKIN_FOREGROUND);
		button.setActiveBorderColor(ColorConstants.SKIN_ACTIVE_BG);
		button.setActiveBgColor(ColorConstants.SKIN_ACTIVE_BG);
		button.setActiveForeground(ColorConstants.SKIN_ACTIVE_FOREGROUND);
		button.setArcWidth(6);
		button.addMouseListener(new MouseAdapter() {
			public void mouseUp(MouseEvent e) {
				confirmAction();
			}
		});
		button.setFont(SWTResourceManager.getFont("微软雅黑", 10, SWT.BOLD));
		GridData gd_savebutton_1 = new GridData(SWT.RIGHT, SWT.FILL, true, true, 1, 1);
		button.setLayoutData(gd_savebutton_1);
		button.setText(Messages.Button_ok);
		
		init();
		return container;
	}

	/**
	 * @Description: 初始化
	 * @author chenxw 
	 */
	private void init() {
		int index = 1;
		for (Supplier supplier : supplierList) {
			GridItem gridItem = new GridItem(grid, SWT.NONE);
			gridItem.setText(0, ObjectUtils.getObjString(index));
			gridItem.setText(1, supplier.getSupplierName());
			gridItem.setData("supplier", supplier);
			gridItem.setHeight(Constants.ROW_HIGHT);
			gridItem.setFont(SWTResourceManager.getFont("微软雅黑", 12, SWT.NORMAL));
			gridItem.setForeground(ColorConstants.FONT_BLACK_COLOR);
			index ++;
		}
		grid.addSelectionListener(new SelectionAdapter() {
			public void widgetDefaultSelected(SelectionEvent e) {
				confirmAction();
			}
		});
	}
	
	/**
	 * @Description: 选择供应商事件
	 * @author chenxw 
	 */
	protected void confirmAction() {
		if(grid.getSelectionCount() > 0 ){
			supplier = (Supplier) grid.getSelection()[0].getData("supplier");
			close(); 
		}else {
			MessageDialog.openError(getShell(), Messages.Tips_select + supplierName + "！");
		}
	}

	
	/**
	 * Return the initial size of the dialog.
	 */
	@Override
	protected Point getInitialSize() {
		return new Point(600, 400);
	}

	public Supplier getSupplier() {
		return supplier;
	}

}
