package com.gx.obe.common.widget.dialog;

import java.text.MessageFormat;
import java.util.ArrayList;
import java.util.List;

import org.eclipse.nebula.widgets.grid.Grid;
import org.eclipse.nebula.widgets.grid.GridColumn;
import org.eclipse.nebula.widgets.grid.GridItem;
import org.eclipse.nebula.widgets.grid.listener.GridCheckedListener;
import org.eclipse.swt.SWT;
import org.eclipse.swt.core.utils.GridUtils;
import org.eclipse.swt.core.widgets.EButton;
import org.eclipse.swt.core.widgets.EDialog;
import org.eclipse.swt.core.widgets.ELink;
import org.eclipse.swt.core.widgets.ESepator;
import org.eclipse.swt.events.MouseAdapter;
import org.eclipse.swt.events.MouseEvent;
import org.eclipse.swt.graphics.Point;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Shell;

import com.gx.obe.ColorConstants;
import com.gx.obe.common.icons.IconsActivator;
import com.gx.obe.common.widget.listener.SelectSupplierListener;
import com.gx.obe.components.core.Constants;
import com.gx.obe.message.Messages;
import com.gx.obe.util.utils.LogUtils;
import com.gx.obe.web.entity.Supplier;
import com.swtdesigner.ResourceManager;

/**
 * @Description: 选择供应商
 * @author guoyr
 */
public class SelectChartSupplierDialog extends EDialog {
	
	private Composite contentComposite;
	private EButton saveBtn;
	private List<Supplier> supplierList;
	private Grid grid;
	private SelectSupplierListener listener;
	private String supplierName; 

	{
		LogUtils.logClass(SelectChartSupplierDialog.class);
	}
	
	/**
	 * Create the dialog.
	 * @param parentShell
	 */
	public SelectChartSupplierDialog(Shell parentShell, String SupplierName, List<Supplier> supplierList, SelectSupplierListener listener) {
		super(parentShell);
		setTitle(MessageFormat.format(Messages.Button_selectFormat, supplierName));
		this.supplierList = supplierList;
		this.listener = listener;
		this.supplierName = SupplierName;
	}

	/**
	 * Create contents of the dialog.
	 * @param parent
	 */
	@Override
	protected Control createDialogArea(Composite parent) {
		Composite container = (Composite) super.createDialogArea(parent);
		GridLayout gl_container = new GridLayout(1, false);
		gl_container.verticalSpacing = 0;
		gl_container.horizontalSpacing = 0;
		gl_container.marginHeight = 0;
		gl_container.marginWidth = 0;
		container.setLayout(gl_container);
		
		contentComposite = new Composite(container, SWT.NONE);
		GridLayout gl_contentComposite = new GridLayout(1, false);
		gl_contentComposite.verticalSpacing = 0;
		gl_contentComposite.horizontalSpacing = 0;
		gl_contentComposite.marginHeight = 0;
		gl_contentComposite.marginWidth = 0;
		contentComposite.setLayout(gl_contentComposite);
		contentComposite.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, true, 1, 1));
		
		Composite buttonComposite = new Composite(contentComposite, SWT.NONE);
		buttonComposite.setLayout(new GridLayout(2, false));
		buttonComposite.setLayoutData(new GridData(SWT.RIGHT, SWT.CENTER, false, false, 1, 1));
		
		ELink allSelect_button = new ELink(buttonComposite, SWT.NONE);
		allSelect_button.addMouseListener(new MouseAdapter() {
			public void mouseUp(MouseEvent e) {
				selectAllHistoryResultAction(true);
			}
		});
		allSelect_button.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, false, false, 1, 1));
		allSelect_button.setImage(ResourceManager.getPluginImage(IconsActivator.PLUGIN_ID, "icons/btn/blue/select_all.png"));
		allSelect_button.setText(Messages.Button_selectAll);
		
		ELink allDesSelect_button = new ELink(buttonComposite, SWT.NONE);
		allDesSelect_button.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, false, false, 1, 1));
		allDesSelect_button.setImage(ResourceManager.getPluginImage(IconsActivator.PLUGIN_ID, "icons/btn/blue/disselect_all.png"));
		allDesSelect_button.setText(Messages.Button_selectInvert);
		allDesSelect_button.addMouseListener(new MouseAdapter() {
			public void mouseUp(MouseEvent e) {
				selectAllHistoryResultAction(false);
			}
		});
		
		ESepator slabel = new ESepator(contentComposite, SWT.SEPARATOR | SWT.HORIZONTAL);
		slabel.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false, 1, 1));
		slabel.setBackground(ColorConstants.SEP_LIGHT_COLOR);
		
		grid = new Grid(contentComposite, SWT.V_SCROLL);
		grid.addMouseListener(new MouseAdapter() {
			@Override
			public void mouseUp(MouseEvent e) {
				gridSelection();
			}
		});
		grid.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, true, 1, 1));
		grid.setAutoHeight(true);
		grid.setHeaderVisible(true);
		
		GridColumn factorNameColumn = new GridColumn(grid, SWT.NONE| SWT.CHECK);
		factorNameColumn.setWordWrap(true);
		factorNameColumn.setText(supplierName);
		
		ESepator label = new ESepator(container, SWT.SEPARATOR | SWT.HORIZONTAL);
		label.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false, 1, 1));
		label.setBackground(ColorConstants.SEP_LIGHT_COLOR);
		
		Composite operateComposite = new Composite(container, SWT.NONE);
		operateComposite.setBackgroundMode(SWT.INHERIT_FORCE);
		operateComposite.setBackgroundImage(ResourceManager.getPluginImage(IconsActivator.PLUGIN_ID, "icons/fill_bg.png"));
		GridLayout gl_operateComposite = new GridLayout(2, false);
		operateComposite.setLayout(gl_operateComposite);
		operateComposite.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false, 1, 1));
		
		saveBtn = new EButton(operateComposite, SWT.NONE);
		saveBtn.addMouseListener(new MouseAdapter() {
			@Override
			public void mouseUp(MouseEvent e) {
				completeAction();
			}
		});
		GridData gd_completeBtn = new GridData(SWT.RIGHT, SWT.CENTER, true, false, 1, 1);
		saveBtn.setLayoutData(gd_completeBtn);
		saveBtn.setImage(ResourceManager.getPluginImage(IconsActivator.PLUGIN_ID, "icons/btn/blue/ok.png"));
		saveBtn.setText(Messages.Button_ok);
		saveBtn.setEnabled(false);
		
		EButton cancel_btn = new EButton(operateComposite, SWT.NONE);
		cancel_btn.setImage(ResourceManager.getPluginImage(IconsActivator.PLUGIN_ID, "icons/btn/blue/close.png"));
		cancel_btn.addMouseListener(new MouseAdapter() {
			@Override
			public void mouseUp(MouseEvent e) {
				cancelAction();
			}
		});
		GridData gd_cancelBtn = new GridData(SWT.FILL, SWT.CENTER, false, false, 1, 1);
		cancel_btn.setLayoutData(gd_cancelBtn);
		cancel_btn.setText(Messages.Button_close);
		init();
		return container;
	}
	
	/**
	 * @Description: 初始化界面
	 */
	private void init(){
		grid.addListener(SWT.Selection, new GridCheckedListener(true));
		grid.setItemHeight(Constants.ROW_HIGHT);
		if(null != supplierList && supplierList.size() > 0){
			for(Supplier supplier : supplierList){
				GridItem item = new GridItem(grid, SWT.WRAP);
				item.setText(0, supplier.getSupplierName());
				item.setData("supplier", supplier);
				item.setChecked(true);
			}
			saveBtn.setEnabled(true);
		}
		
	}
	/**
	 * @Description: 表格选取事件
	 * @author guoyr 
	 */
	private void gridSelection(){
		GridItem[] items = grid.getItems();
		int checkCount = 0;
		for(GridItem item : items){
			if(item.getChecked()){
				checkCount ++;
			}
		}
		saveBtn.setEnabled(checkCount > 0);
	}
	/**
	 * @Description: 保存
	 */
	private void completeAction(){
		if(saveBtn.getEnabled()){
			GridItem[] items = grid.getItems();
			List<Supplier> selectEvaluationFactorList = new ArrayList<Supplier>();
			for(GridItem item : items){
				if(item.getChecked()){
					Supplier supplier = (Supplier)item.getData("supplier");
					selectEvaluationFactorList.add(supplier);
				}
			}
			if(selectEvaluationFactorList.size() > 0){
				listener.setSupplierList(selectEvaluationFactorList);
				getShell().close();
			}
		}
	}
	/**
	 * @Description: 全选、反选
	 * @author guoyr
	 * @param selectAll
	 */
	private void selectAllHistoryResultAction(boolean selectAll){
		GridUtils.checkAll(grid, 0, selectAll);
		saveBtn.setEnabled(selectAll);
	}
	/**
	 * @Description: 取消
	 */
	private void cancelAction(){
		getShell().close();
	}


	
	/**
	 * Return the initial size of the dialog.
	 */
	@Override
	protected Point getInitialSize() {
		return new Point(500, 300);
	}
}
